@@ -1091,8 +1091,7 @@ void KopeteContactListView::metaContactPopup( Kopete::MetaContact *metaContact,
 
 			KMenu *contactMenu = c->popupMenu();
 			connect( popup, SIGNAL(aboutToHide()), contactMenu, SLOT(deleteLater()) );
-			QString nick = c->property(Kopete::Global::Properties::self()->nickName()).value().toString();
-			QString text = nick.isEmpty() ?  c->contactId() : i18nc( "Translators: format: '<displayName> (<id>)'", "%2 <%1>", c->contactId(), nick );
+			QString text = i18nc( "Translators: format: '<displayName> (<id>)'", "%2 <%1>", c->contactId(), c->nickName() );
 			text=text.replace('&',"&&"); // cf BUG 115449
 
 			if ( text.length() > 41 )
